/* -*- mode: C; c-file-style: "bsd" -*- */

#ifndef __PORBIT_EXTRAS_H__
#define __PORBIT_EXTRAS_H__

#include <orb/orbit.h>

void porbit_set_cookie (const char *cookie);
void porbit_set_use_gmain (gboolean set);
void porbit_set_check_cookies (gboolean set);

#endif /* __PORBIT_EXTRAS_H__ */
